@@ -2,9 +2,9 @@
 # Mail::SPF::Mod::Exp
 # SPF record "exp" modifier class.
 #
-# (C) 2005-2012 Julian Mehnle <julian@mehnle.net>
+# (C) 2005-2006 Julian Mehnle <julian@mehnle.net>
 #     2005      Shevek <cpan@anarres.org>
-# $Id: Exp.pm 57 2012-01-30 08:15:31Z julian $
+# $Id: Exp.pm 30 2006-11-27 19:55:10Z Julian Mehnle $
 #
 ##############################################################################
 
@@ -24,6 +24,7 @@ use base 'Mail::SPF::GlobalMod';
 
 use Error ':try';
 
+use Mail::SPF::Result;
 use Mail::SPF::MacroString;
 
 use constant TRUE   => (0 == 0);
@@ -32,8 +33,6 @@ use constant FALSE  => not TRUE;
 use constant name           => 'exp';
 use constant name_pattern   => qr/${\name}/i;
 
-use constant precedence     => 0.2;
-
 =head1 DESCRIPTION
 
 An object of class B<Mail::SPF::Mod::Exp> represents an SPF record modifier of
@@ -60,11 +59,10 @@ See L<Mail::SPF::Mod/new>.
 
 =back
 
-=item B<new_from_string($text, %options)>: returns I<Mail::SPF::Mod::Exp>;
-throws I<Mail::SPF::ENothingToParse>, I<Mail::SPF::EInvalidMod>
+=item B<new_from_string($text)>: returns I<Mail::SPF::Mod::Exp>; throws
+I<Mail::SPF::ENothingToParse>, I<Mail::SPF::EInvalidMod>
 
-Creates a new SPF record C<exp> modifier object by parsing the string and
-any options given.
+Creates a new SPF record C<exp> modifier object by parsing the given string.
 
 =back
 
@@ -82,10 +80,6 @@ Returns B<'exp'>.
 
 Returns a regular expression that matches a modifier name of B<'exp'>.
 
-=item B<precedence>: returns I<real>
-
-Returns a precedence value of B<0.2>.  See L<Mail::SPF::Mod/precedence>.
-
 =back
 
 =head2 Instance methods
@@ -134,16 +128,16 @@ details.
 
 sub process {
     my ($self, $server, $request, $result) = @_;
-
+    
     try {
         my $exp_domain = $self->{domain_spec}->new(server => $server, request => $request);
         my $txt_packet = $server->dns_lookup($exp_domain, 'TXT');
         my @txt_rrs = grep($_->type eq 'TXT', $txt_packet->answer);
         @txt_rrs > 0
-            or $server->throw_result('permerror', $request,
+            or throw Mail::SPF::Result::PermError($server, $request,
                 "No authority explanation string available at domain '$exp_domain'");  # RFC 4408, 6.2/4
         @txt_rrs == 1
-            or $server->throw_result('permerror', $request,
+            or throw Mail::SPF::Result::PermError($server, $request,
                 "Redundant authority explanation strings found at domain '$exp_domain'");  # RFC 4408, 6.2/4
         my $explanation = Mail::SPF::MacroString->new(
             text            => join('', $txt_rrs[0]->char_str_list),
@@ -156,7 +150,7 @@ sub process {
     # Ignore DNS and other errors:
     catch Mail::SPF::EDNSError with {}
     catch Mail::SPF::Result::Error with {};
-
+    
     return;
 }
 
@@ -168,7 +162,7 @@ See L<Mail::SPF::Mod> for other supported instance methods.
 
 L<Mail::SPF>, L<Mail::SPF::Mod>, L<Mail::SPF::Term>, L<Mail::SPF::Record>
 
-L<http://tools.ietf.org/html/rfc4408>
+L<http://www.ietf.org/rfc/rfc4408.txt>
 
 For availability, support, and license information, see the README file
 included with Mail::SPF.
