@@ -3,8 +3,8 @@
 # Abstract base class for SPF record mechanisms that operate on the SMTP
 # sender's IP address.
 #
-# (C) 2005-2012 Julian Mehnle <julian@mehnle.net>
-# $Id: SenderIPAddrMech.pm 57 2012-01-30 08:15:31Z julian $
+# (C) 2005-2006 Julian Mehnle <julian@mehnle.net>
+# $Id: SenderIPAddrMech.pm 30 2006-11-27 19:55:10Z Julian Mehnle $
 #
 ##############################################################################
 
@@ -61,7 +61,7 @@ L<Mail::SPF::Mech::A>,
 L<Mail::SPF::Mech::MX>,
 L<Mail::SPF::Mech::PTR>
 
-L<http://tools.ietf.org/html/rfc4408>
+L<http://www.ietf.org/rfc/rfc4408.txt>
 
 For availability, support, and license information, see the README file
 included with Mail::SPF.
